BysquareDecodeError class

Thrown when decoding fails due to bad input, checksum mismatch, or unsupported format version.

Implemented types

Constructors

BysquareDecodeError(String message, [Map<String, dynamic>? extensions])
const

Properties

extensions Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited