CustomerParty class

Constructors

CustomerParty({required String partyName, String? companyTaxId, String? companyVatId, String? companyRegisterId, String? partyIdentification})
const

Properties

companyRegisterId String?
final
companyTaxId String?
final
companyVatId String?
final
hashCode int
The hash code for this object.
no setterinherited
partyIdentification String?
final
partyName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited