DirectDebit class final

A direct debit payment.

Inheritance

Constructors

DirectDebit({double? amount, required String currencyCode, String? paymentDueDate, String? variableSymbol, String? constantSymbol, String? specificSymbol, String? originatorsReferenceInformation, String? paymentNote, required List<BankAccount> bankAccounts, required Beneficiary beneficiary, int? directDebitScheme, int? directDebitType, String? ddVariableSymbol, String? ddSpecificSymbol, String? ddOriginatorsReferenceInformation, String? mandateId, String? creditorId, String? contractId, double? maxAmount, String? validTillDate})
const

Properties

amount double?
finalinherited
bankAccounts List<BankAccount>
finalinherited
beneficiary Beneficiary
finalinherited
constantSymbol String?
finalinherited
contractId String?
final
creditorId String?
final
currencyCode String
finalinherited
ddOriginatorsReferenceInformation String?
final
ddSpecificSymbol String?
final
ddVariableSymbol String?
final
directDebitScheme int?
final
directDebitType int?
final
hashCode int
The hash code for this object.
no setterinherited
mandateId String?
final
maxAmount double?
final
originatorsReferenceInformation String?
finalinherited
paymentDueDate String?
finalinherited
paymentNote String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specificSymbol String?
finalinherited
type int
finalinherited
validTillDate String?
final
variableSymbol String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited