InvoiceDataModel class
Root data model for an Invoice by square QR code.
Constructors
-
InvoiceDataModel({required int documentType, required String invoiceId, required String issueDate, String? taxPointDate, String? orderId, String? deliveryNoteId, required String localCurrencyCode, String? foreignCurrencyCode, double? currRate, double? referenceCurrRate, required SupplierParty supplierParty, required CustomerParty customerParty, int? numberOfInvoiceLines, String? invoiceDescription, SingleInvoiceLine? singleInvoiceLine, required List<
TaxCategorySummary> taxCategorySummaries, required MonetarySummary monetarySummary, int? paymentMeans}) -
const
Properties
- currRate → double?
-
final
- customerParty → CustomerParty
-
final
- deliveryNoteId → String?
-
final
- documentType → int
-
final
- foreignCurrencyCode → String?
-
ISO 4217 foreign currency code. Required when currRate is set.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- invoiceDescription → String?
-
final
- invoiceId → String
-
Required invoice identifier.
final
- issueDate → String
-
Required issue date in
YYYYMMDDformat.final - localCurrencyCode → String
-
ISO 4217 currency code.
final
- monetarySummary → MonetarySummary
-
final
- numberOfInvoiceLines → int?
-
Mutually exclusive with singleInvoiceLine.
final
- orderId → String?
-
final
- paymentMeans → int?
-
Bitmask of PaymentMean values.
final
- referenceCurrRate → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleInvoiceLine → SingleInvoiceLine?
-
Mutually exclusive with numberOfInvoiceLines.
final
- supplierParty → SupplierParty
-
final
-
taxCategorySummaries
→ List<
TaxCategorySummary> -
final
- taxPointDate → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited