Month class abstract final

Months as bit-flag constants. Combine with bitwise OR (or plain addition) for standing orders that span multiple months.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

april → const int
august → const int
december → const int
february → const int
january → const int
july → const int
june → const int
march → const int
may → const int
november → const int
october → const int
september → const int