PayDataModel class

Root data model for a PAY by square QR code.

Constructors

PayDataModel({String? invoiceId, required List<Payment> payments})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
invoiceId String?
Invoice or internal identifier. Max 10 characters.
final
payments List<Payment>
One or more payments. The preferred payment must be first.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited