PayEncodeOptions class

Options for payEncode.

Constructors

PayEncodeOptions({bool deburr = true, bool validate = true, int version = Version.v120})
const

Properties

deburr bool
Strip diacritics from text fields before encoding.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validate bool
Validate the data model before encoding. Defaults to true.
final
version int
Bysquare specification version to embed in the QR header.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited