version property
Bysquare specification version to embed in the QR header.
Defaults to Version.v120. Pass Version.v100 or Version.v110 for compatibility with older apps that do not require a beneficiary name.
Implementation
final int version;
Bysquare specification version to embed in the QR header.
Defaults to Version.v120. Pass Version.v100 or Version.v110 for compatibility with older apps that do not require a beneficiary name.
final int version;