PaymentOptions class abstract final

Payment type classifier.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

directDebit → const int
Direct debit; fill DirectDebit fields.
paymentOrder → const int
Single payment order.
standingOrder → const int
Recurring payment; fill StandingOrder fields.