PaymentOrder class final

A single, one-time payment order.

Inheritance

Constructors

PaymentOrder({double? amount, required String currencyCode, String? paymentDueDate, String? variableSymbol, String? constantSymbol, String? specificSymbol, String? originatorsReferenceInformation, String? paymentNote, required List<BankAccount> bankAccounts, required Beneficiary beneficiary})
const

Properties

amount double?
finalinherited
bankAccounts List<BankAccount>
finalinherited
beneficiary Beneficiary
finalinherited
constantSymbol String?
finalinherited
currencyCode String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
originatorsReferenceInformation String?
finalinherited
paymentDueDate String?
finalinherited
paymentNote String?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specificSymbol String?
finalinherited
type int
finalinherited
variableSymbol String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited