PostalAddress class

Constructors

PostalAddress({String? streetName, String? buildingNumber, String? cityName, String? postalZone, String? state, String? country})
const

Properties

buildingNumber String?
final
cityName String?
final
country String?
final
hashCode int
The hash code for this object.
no setterinherited
postalZone String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
final
streetName String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited