SingleInvoiceLine class

Constructors

SingleInvoiceLine({String? orderLineId, String? deliveryNoteLineId, String? itemName, String? itemEanCode, String? periodFromDate, String? periodToDate, double? invoicedQuantity})
const

Properties

deliveryNoteLineId String?
final
hashCode int
The hash code for this object.
no setterinherited
invoicedQuantity double?
final
itemEanCode String?
final
itemName String?
final
orderLineId String?
final
periodFromDate String?
YYYYMMDD
final
periodToDate String?
YYYYMMDD
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited