Version class abstract final

Bysquare format version encoded in the QR header (4-bit field).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

v100 → const int
1.0.0 - Created from original specification (2013-02-22).
v110 → const int
1.1.0 - Added beneficiary name and address fields (2015-06-24).
v120 → const int
1.2.0 - Beneficiary name is now required (2025-04-01).