BankAccount class
IBAN + optional BIC of a payment recipient.
Constructors
- BankAccount({required String iban, String? bic})
-
const
Properties
- bic → String?
-
Bank Identification Code / SWIFT code (ISO 9362). Optional.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iban → String
-
International Bank Account Number (ISO 13616).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited