Payment class sealed
Base class for all payment types.
- Implementers
Properties
- amount → double?
-
final
-
bankAccounts
→ List<
BankAccount> -
final
- beneficiary → Beneficiary
-
final
- constantSymbol → String?
-
final
- currencyCode → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- originatorsReferenceInformation → String?
-
final
- paymentDueDate → String?
-
final
- paymentNote → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specificSymbol → String?
-
final
- type → int
-
final
- variableSymbol → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited