StandingOrder class final

A recurring (standing order) payment.

Inheritance

Constructors

StandingOrder({double? amount, required String currencyCode, String? paymentDueDate, String? variableSymbol, String? constantSymbol, String? specificSymbol, String? originatorsReferenceInformation, String? paymentNote, required List<BankAccount> bankAccounts, required Beneficiary beneficiary, int? day, int? month, required String periodicity, String? lastDate})
const

Properties

amount double?
finalinherited
bankAccounts List<BankAccount>
finalinherited
beneficiary Beneficiary
finalinherited
constantSymbol String?
finalinherited
currencyCode String
finalinherited
day int?
Day of the month (1-31) or day of the week (1-7) for weekly orders.
final
hashCode int
The hash code for this object.
no setterinherited
lastDate String?
Last payment date in YYYYMMDD format. Order is cancelled after this.
final
month int?
Bitmask of Month values indicating active months.
final
originatorsReferenceInformation String?
finalinherited
paymentDueDate String?
finalinherited
paymentNote String?
finalinherited
periodicity String
One of the Periodicity constants.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specificSymbol String?
finalinherited
type int
finalinherited
variableSymbol String?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited